import { UnityAction } from '@/utils/utils';
import { Collapse, Empty, Spin, Tabs } from 'antd';
import { useEffect, useState } from 'react';
import ThresholdBar from './ThresholdBar';
import styles from './VideoAnalysis.less';

const { TabPane } = Tabs;
const { Panel } = Collapse;

function VideoAnalysis(props) {
  const { data, loading } = props;

  const [prevKey, setPrevKey] = useState();
  const [selectedName, setSelectedName] = useState('');

  const handleCollapse = (key) => {
    if (key === prevKey) return;
    setPrevKey(key);
    const device = data.list.find((item) => item.id === key)?.device_name;
    if (device) {
      UnityAction.sendMsg('SynCam', device);
    }
  };

  useEffect(() => {
    UnityAction.on('SynCam', selectedItem);
    return () => UnityAction.off('SynCam', selectedItem);
  }, [data?.list]);

  //滚动到相应位置
  const selectedItem = (e) => {
    setSelectedName(e);
    const dom = document.querySelector(`div[data-name="${e}"]`);
    if (dom) {
      let v = document.getElementById('videoContent');
      v.scrollTop = dom.offsetTop;
    }
  };

  return (
    <Spin spinning={loading}>
      <div
        id="videoContent"
        className={styles.page}
        style={{ height: 'calc(100vh - 580px)', overflow: 'auto' }}
      >
        {data?.list?.length > 0 ? (
          data?.list?.map((item) => (
            <div data-name={item.device_name}>
              <Collapse
                defaultActiveKey={[item.id]}
                key={item.id}
                className={
                  selectedName == item.device_name || prevKey == item.id
                    ? styles.tableSelect
                    : styles.table
                }
                expandIcon={() => (
                  <div className={styles.typeText}>视频报警</div>
                )}
                onChange={(e) => {
                  handleCollapse(item.id);
                }}
              >
                <Panel header={item.device_name} key={item.id}>
                  <AnalysisContent item={item} />
                </Panel>
              </Collapse>
            </div>
          ))
        ) : (
          <Empty />
        )}
      </div>
    </Spin>
  );
}

function AnalysisContent({ item }) {
  const handleImgClick = () => {
    localStorage.setItem('preview', JSON.stringify(item.data));
    UnityAction.sendMsg('SensorPic');
  };

  const renderContent = (key, item) => {
    let content = '';
    switch (key) {
      case 1:
        content = (
          <>
            <div className={styles.label}>画面报警：</div>
            <div className={styles.content}>
              {item.event_type}
              <img
                className={styles.img}
                src={item.url}
                onClick={handleImgClick}
              />
            </div>
          </>
        );
        break;
      case 2:
        content = (
          <>
            <div className={styles.contentFlex}>
              <div>参数：温度</div>
              <div className={styles.threshold}>
                <span>阈值范围：</span>
                <div style={{ width: '180px' }}>
                  <ThresholdBar current={0.5} thresholds={[0, 1]} />
                </div>
              </div>

              <div>
                状态：<span className={styles.textAbnormal}>异常</span>
              </div>
            </div>
          </>
        );
        break;
      case 3:
        content = (
          <>
            <div className={styles.contentFlex}>
              <div>原液位：12.01</div>
              <div> 仪表液位：12.12 </div>

              <div>
                状态：<span className={styles.textAbnormal}>异常</span>
              </div>
            </div>
          </>
        );
        break;
    }
    return content;
  };

  return (
    <div className={styles.box}>
      <div className={styles.item}>
        {renderContent(3, item)}
        {/* <div className={styles.content}>
          {item.event_type}
          <img className={styles.img} src={item.url} onClick={handleImgClick} />
        </div> */}
      </div>
    </div>
  );
}

export default VideoAnalysis;
